@@ -1,5 +1,6 @@
 package GitLab::API::v4::Config;
-$GitLab::API::v4::Config::VERSION = '0.15';
+our $VERSION = '0.20';
+
 =encoding utf8
 
 =head1 NAME
@@ -25,13 +26,13 @@ L</SYNOPSIS>.
 
 =cut
 
-use Types::Standard -types;
-use Types::Common::String -types;
-use Path::Tiny;
-use JSON;
-use Log::Any qw( $log );
 use Getopt::Long;
 use IO::Prompter;
+use JSON;
+use Log::Any qw( $log );
+use Path::Tiny;
+use Types::Common::String -types;
+use Types::Standard -types;
 
 use Moo;
 use strictures 2;
@@ -257,12 +258,17 @@ sub configure {
 1;
 __END__
 
+=head1 SUPPORT
+
+See L<GitLab::API::v4/SUPPORT>.
+
 =head1 AUTHORS
 
-See L<GitLab::API::v4/AUTHOR> and L<GitLab::API::v4/CONTRIBUTORS>.
+See L<GitLab::API::v4/AUTHORS>.
 
-=head1 LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+See L<GitLab::API::v4/COPYRIGHT AND LICENSE>.
+
+=cut
 
